# Popover

[![CI Status](http://img.shields.io/travis/corin8823/Popover.svg?style=flat)](https://travis-ci.org/corin8823/Popover)
[![Version](https://img.shields.io/cocoapods/v/Popover.svg?style=flat)](http://cocoapods.org/pods/Popover)
[![License](https://img.shields.io/cocoapods/l/Popover.svg?style=flat)](http://cocoapods.org/pods/Popover)
[![Platform](https://img.shields.io/cocoapods/p/Popover.svg?style=flat)](http://cocoapods.org/pods/Popover)

## Description and [appetize.io`s DEMO](https://appetize.io/app/q4n81yf0aakkx20x2cejh107b4)

![](https://github.com/corin8823/Popover/blob/master/ScreenShots/Screenshot.gif)

## Usage

To run the example project, clone the repo, and run `pod install` from the Example directory first.

### Simple

```swift
let startPoint = CGPoint(x: self.view.frame.width - 60, y: 55)
let aView = UIView(frame: CGRect(x: 0, y: 0, width: self.view.frame.width, height: 180))
var popover = Popover()
popover.show(aView, point: startPoint)
```

### Custom

```swift
@IBOutlet weak var leftBottomButton: UIButton!

let width = self.view.frame.width / 4
let aView = UIView(frame: CGRect(x: 0, y: 0, width: width, height: width))
let options = [
  .Type(.Up),
  .CornerRadius(width / 2),
  .AnimationIn(0.3),
  .BlackOverlayColor(UIColor.redColor()),
  .ArrowSize(CGSizeZero)
  ] as [PopoverOption]
var popover = Popover(options: options, showHandler: {
  println("showHandler")
  }, dismissHandler: {
    println("dismissHandler")
})
popover.show(aView, fromView: self.leftBottomButton)
```

## Requirements
- iOS 7.0+
- Xcode 7

## Installation

### CocoaPods(iOS 8+)
Popover is available through [CocoaPods](http://cocoapods.org). To install
it, simply add the following line to your `Podfile`:

```ruby
use_frameworks!
pod "Popover"
```

### Carthage (iOS 8+)
You can use [Carthage](https://github.com/Carthage/Carthage) to install `Popover` by adding it to your `Cartfile`:
```ruby
github "corin8823/Popover"
```

### Manual Installation
The class file required for Popover is located in the Classes folder in the root of this repository as listed below:
```
Popover.swift
```

## Customization

- ``case ArrowSize(CGSize)``
- ``case AnimationIn(NSTimeInterval)``
- ``case AnimationOut(NSTimeInterval)``
- ``case CornerRadius(CGFloat)``
- ``case SideEdge(CGFloat)``
- ``case BlackOverlayColor(UIColor)``
- ``case OverlayBlur(UIBlurEffectStyle)``
- ``case Type(Popover.PopoverType)``
- ``case Color(UIColor)``

## Acknowledgments
Inspired by [DXPopover](https://github.com/xiekw2010/DXPopover) in [xiekw2010](https://github.com/xiekw2010)

## License

Popover is available under the MIT license. See the LICENSE file for more info.
